# prevenger

[![Build Status](https://travis-ci.org/twocucao/prevenger.svg?branch=master)](https://travis-ci.org/twocucao/prevenger)
![pyversions](https://img.shields.io/badge/python%20-3.7%2B-blue.svg)
![pypi](https://img.shields.io/pypi/v/nine.svg)
[![contributions welcome](https://img.shields.io/badge/contributions-welcome-ff69b4.svg)](https://github.com/twocucao/prevenger/issues)

平时经常使用的代码，拷贝在身边，一用好多年

> 紧跟社区最佳实践

## 感谢

> 感谢开源社区人的无私奉献

---
ChangeLog:
 - 2019-05-09: 初始化

## License

MIT

